﻿using ELTE.TravelAgency.Models;
using System;
using System.Linq;
using System.Web.Mvc;

namespace ELTE.TravelAgency.Controllers
{
    /// <summary>
    /// Vezérlő típusa
    /// </summary>
    public class HomeController : Controller
    {
        private TravelAgencyEntities _entities;

        /// <summary>
        /// Vezérlő példányosítása.
        /// </summary>
        public HomeController() 
        {
            _entities = new TravelAgencyEntities();

            ViewBag.Cities = _entities.City.ToArray(); // a városokat berakjuk egy tömbbe
        }

        /// <summary>
        /// Épületek listázása.
        /// </summary>
        /// <returns>Az épületek listájának nézete.</returns>
        public ActionResult Index()
        {
            return View("Index", _entities.Building.Include("City"));
        }


        /// <summary>
        /// Épületek listázása.
        /// </summary>
        /// <param name="cityId">Város azonosítója.</param>
        /// <returns>Az épületek listájának nézete.</returns>
        public ActionResult List(Int32 cityId)
        {
            // ha hibás az azonosító
            if (!_entities.City.Any(c => c.Id == cityId))
                return HttpNotFound(); // átirányítjuk a nem talált oldalra

            // megkeressük a megfelelő város szonosítókat 
            return View("Index", _entities.Building.Include("City").Where(b => b.CityId == cityId));
        }

        /// <summary>
        /// Épület részleteinek nézete.
        /// </summary>
        /// <param name="buildingId">Épület azonosítója.</param>
        /// <returns>Az épület részletes nézete.</returns>
        public ActionResult Details(Int32 buildingId)
        {
            Building building = _entities.Building.Include("City").Include("Apartment").FirstOrDefault(b => b.Id == buildingId);

            if (building == null)
                return HttpNotFound(); // átirányítjuk a nem talált oldalra

            ViewBag.Title = "Épület részletei: " + building.Name + " (" + building.City.Name + ")"; // az oldal címe

            return View("Details", building);
        }
	}
}